@@ -1,4 +1,4 @@
-EM2 <- function (y, X = NULL, ETA = NULL, R = NULL, init = NULL, iters = 50, 
+EM2 <-function (y, X = NULL, ETA = NULL, R = NULL, init = NULL, iters = 50, 
           REML = TRUE, draw = TRUE, silent = FALSE) 
 {
   if (is.null(X) & is.null(ETA)) {
@@ -180,8 +180,8 @@ EM2 <- function (y, X = NULL, ETA = NULL, R = NULL, init = NULL, iters = 50,
         rrr <- indexK[k]
         Kinv <- solve(ETA[[rrr]][[2]])
         var.com[[k]] = ((t(thetaHat[pairs.a[[rrr]], ]) %*% 
-                           Kinv %*% thetaHat[pairs.a[[rrr]], ]) + matrixcalc::matrix.trace(Kinv %*% 
-                                                                                             CInv[pairs.a[[rrr]], pairs.a[[rrr]]] * as.numeric(varE)))/nrow(ETA[[rrr]][[2]])
+                           Kinv %*% thetaHat[pairs.a[[rrr]], ]) + matrix.trace(Kinv %*% 
+                                                                                 CInv[pairs.a[[rrr]], pairs.a[[rrr]]] * as.numeric(varE)))/nrow(ETA[[rrr]][[2]])
       }
       var.com[[length(var.com)]] = varE
       for (k in 1:length(var.com.sto)) {
