@@ -26,7 +26,7 @@ D <- D.mat(CPgeno) # dominance relationship matrix
 E <- E.mat(CPgeno) # epistatic relationship matrix
 
 ETA.ADE <- list(list(Z=Za,K=A),list(Z=Zd,K=D),list(Z=Ze,K=E))
-ans.ADE <- mmer(y=y, Z=ETA.ADE,silent = TRUE)
+ans.ADE <- mmer(Y=y, Z=ETA.ADE,silent = TRUE)
 (H2 <- sum(ans.ADE$var.comp[1:3,1])/sum(ans.ADE$var.comp[,1]))
 (h2 <- sum(ans.ADE$var.comp[1,1])/sum(ans.ADE$var.comp[,1]))
 
@@ -56,7 +56,7 @@ Z2 <- model.matrix(~as.factor(geno)-1, data=HDdata)
 # Fit the model
 y <- HDdata$sugar
 ETA <- list(GCA=list(Z=Z1), SCA=list(Z=Z2)) # Zu component
-modHD <- mmer(y=y, Z=ETA,silent = TRUE)
+modHD <- mmer(Y=y, Z=ETA,silent = TRUE)
 summary(modHD)
 Vgca <- modHD$var.comp[1,1]
 Vsca <- modHD$var.comp[2,1]
@@ -81,9 +81,9 @@ y <- CPpheno$color # response
 Za <- diag(length(y)) # inidence matrix for random effect
 A <- A.mat(CPgeno) # additive relationship matrix
 ETA.A <- list(add=list(Z=Za,K=A)) # create random component
-ans.A <- mmer(y=y, Z=ETA.A, W=CPgeno, silent=TRUE) # fit the model
+ans.A <- mmer(Y=y, Z=ETA.A, W=CPgeno, silent=TRUE) # fit the model
 ### if you have a genetic map you can use it
-ans.B <- mmer(y=y, Z=ETA.A, W=CPgeno, silent=TRUE, map=my.map) # fit the model
+ans.B <- mmer(Y=y, Z=ETA.A, W=CPgeno, silent=TRUE, map=my.map) # fit the model
 
 ## ------------------------------------------------------------------------
 data(PolyData)
@@ -103,7 +103,7 @@ Z1 <- diag(length(yy))
 ETA <- list( list(Z=Z1, K=K1)) # random effects for genotypes
 # run the model
 models <- c("additive","1-dom-alt","1-dom-ref","2-dom-alt","2-dom-ref")
-ans2 <- mmer(y=yy, Z=ETA, W=marks, method="EMMA", 
+ans2 <- mmer(Y=yy, Z=ETA, W=marks, method="EMMA", 
               ploidy=4, models=models[1], silent = TRUE)
 summary(ans2)
 
@@ -122,7 +122,7 @@ y.trn <- y
 vv <- sample(1:length(y),round(length(y)/5))
 y.trn[vv] <- NA
 ETA <- list(g=list(Z=Z1, K=K))
-ans <- mmer(y=y.trn, Z=ETA, method="EMMA", silent = TRUE) # kinship based
+ans <- mmer(Y=y.trn, Z=ETA, method="EMMA", silent = TRUE) # kinship based
 cor(ans$u.hat$g[vv],y[vv])
 ## maximum prediction value that can be achieved
 sqrt(ans$var.comp[1,1]/sum(ans$var.comp[,1]))
@@ -160,7 +160,7 @@ vv1 <- which(!is.na(hybs$yield))
 vv2 <- sample(vv1, 100)
 y.trn[vv2] <- NA
 ETA2 <- list(GCA1=list(Z=Z1, K=A.dent), GCA2=list(Z=Z2, K=A.flint)) 
-anss2 <- mmer(y=y.trn, Z=ETA2, method="EM", silent=TRUE) 
+anss2 <- mmer(Y=y.trn, Z=ETA2, method="EM", silent=TRUE) 
 summary(anss2)
 cor(anss2$fitted.y[vv2], hybs$yield[vv2])
 
